@@ -27,8 +27,8 @@
 #include "gva-game-store.h"
 #include "gva-main.h"
 #include "gva-preferences.h"
-#include "gva-search.h"
 #include "gva-ui.h"
+#include "gva-util.h"
 
 #define SQL_SELECT_GAMES \
         "SELECT %s FROM available"
@@ -102,32 +102,23 @@ tree_view_search_equal (GtkTreeModel *model,
                         const gchar *key,
                         GtkTreeIter *iter)
 {
-        const gchar *valid_chars;
-        gchar **str_array;
         gchar *title;
+        gchar *s1, *s2;
         gboolean retval;
 
-        /* Filter out spaces and punctuation so that, e.g. typing
-         * "mspacman" will match "Ms. Pac-Man". */
-
-        valid_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                      "abcdefghijklmnopqrstuvwxyz"
-                      "0123456789";
-
         g_assert (column == GVA_GAME_STORE_COLUMN_DESCRIPTION);
         gtk_tree_model_get (model, iter, column, &title, -1);
         g_assert (title != NULL);
 
-        g_strcanon (title, valid_chars, '?');
-        str_array = g_strsplit_set (title, "?", -1);
-        g_free (title);
-        title = g_strjoinv (NULL, str_array);
-        g_strfreev (str_array);
+        s1 = gva_search_collate_key (key);
+        s2 = gva_search_collate_key (title);
 
         /* Return FALSE if the row matches. */
-        retval = (g_ascii_strncasecmp (key, title, strlen (key)) != 0);
+        retval = (strncmp (s1, s2, strlen (s1)) != 0);
 
         g_free (title);
+        g_free (s1);
+        g_free (s2);
 
         return retval;
 }
@@ -214,16 +205,18 @@ gva_tree_view_update (GError **error)
                 {
                         gchar *text;
 
-                        text = gva_search_get_last_search ();
+                        text = gva_main_get_last_search ();
                         if (text != NULL && *text != '\0')
                                 g_string_append_printf (
                                         expr, "(name LIKE '%s' OR "
-                                        "category LIKE '%%%s%%' OR "
+					"bios MATCH '%s' OR "
+                                        "category MATCH '%s' OR "
                                         "sourcefile LIKE '%s' OR "
-                                        "description LIKE '%%%s%%' OR "
-                                        "manufacturer LIKE '%%%s%%' OR "
+                                        "description MATCH '%s' OR "
+                                        "manufacturer MATCH '%s' OR "
                                         "year LIKE '%s')",
-                                        text, text, text, text, text, text);
+                                        text, text, text, text,
+                                        text, text, text);
                         else
                                 g_string_append (expr, "name ISNULL");
                         g_free (text);
@@ -308,10 +301,16 @@ gva_tree_view_run_query (const gchar *expr,
 
         gdk_window_set_cursor (window, cursor);
         gtk_widget_set_sensitive (GTK_WIDGET (view), FALSE);
+
         model = gva_game_store_new_from_query (string->str, error);
-        sensitive = (gtk_tree_model_iter_n_children (model, NULL) > 0);
-        gtk_widget_set_sensitive (GTK_WIDGET (view), sensitive);
-        gdk_window_set_cursor (window, NULL);
+
+        /* Don't touch widgets if gtk_main_quit() has been called. */
+        if (!gtk_main_iteration_do (FALSE))
+        {
+                sensitive = (gtk_tree_model_iter_n_children (model, NULL) > 0);
+                gtk_widget_set_sensitive (GTK_WIDGET (view), sensitive);
+                gdk_window_set_cursor (window, NULL);
+        }
 
         gdk_cursor_unref (cursor);
         g_string_free (string, TRUE);
@@ -654,6 +653,49 @@ gva_tree_view_popup_menu_cb (GtkTreeView *view)
         return tree_view_show_popup_menu (NULL);
 }
 
+/**
+ * gva_tree_view_query_tooltip_cb:
+ * @view: the main tree view
+ * @x: the x coordinate of the cursor position where the request has
+ *     been emitted
+ * @y: the y coordinate of the cursor position where the request has
+ *     been emitted
+ * @keyboard_mode: %TRUE if the tooltip was triggered using the keyboard
+ * @tooltip: a #GtkTooltip
+ *
+ * Handles tooltips for the main tree view.
+ *
+ * Returns: %TRUE if @tooltip should be shown right now, %FALSE otherwise
+ **/
+gboolean
+gva_tree_view_query_tooltip_cb (GtkTreeView *view,
+                                gint x,
+                                gint y,
+                                gboolean keyboard_mode,
+                                GtkTooltip *tooltip)
+{
+        GtkTreeViewColumn *column;
+        GtkTreePath *path;
+        GtkTreeIter iter;
+
+        if (!gtk_tree_view_get_tooltip_context (
+                view, &x, &y, keyboard_mode, NULL, &path, &iter))
+                return FALSE;
+
+        /* Figure out which column we're pointing at. */
+        if (keyboard_mode)
+                gtk_tree_view_get_cursor (view, NULL, &column);
+        else
+                gtk_tree_view_get_path_at_pos (
+                        view, x, y, NULL, &column, NULL, NULL);
+
+        /* Restrict the tip area to a single cell. */
+        gtk_tree_view_set_tooltip_cell (view, tooltip, path, column, NULL);
+
+        return gva_columns_query_tooltip (column, path, tooltip);
+
+}
+
 /**
  * gva_tree_view_row_activated_cb:
  * @view: the main tree view
