@@ -18,10 +18,6 @@
 
 #include "gva-ui.h"
 
-#ifdef WITH_GNOME
-#include <gnome.h>
-#endif
-
 #include <glade/glade.h>
 #include <glade/glade-build.h>
 
@@ -95,11 +91,7 @@ action_about_cb (GtkAction *action)
 
         gtk_show_about_dialog (
                 GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW),
-#if GTK_CHECK_VERSION (2, 12, 0)
                 "program-name", PACKAGE_NAME,
-#else
-                "name", PACKAGE_NAME,
-#endif
                 "version", PACKAGE_VERSION,
                 "comments", _("M.A.M.E. Front-End"),
                 "copyright", copyright,
@@ -134,28 +126,7 @@ action_about_cb (GtkAction *action)
 static void
 action_contents_cb (GtkAction *action)
 {
-#ifdef WITH_GNOME
-        GtkWidget *dialog;
-        GError *error = NULL;
-
-        if (gnome_help_display ("gnome-video-arcade.xml", NULL, &error))
-                return;
-
-        dialog = gtk_message_dialog_new_with_markup (
-                GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW),
-                GTK_DIALOG_DESTROY_WITH_PARENT,
-                GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                "<big><b>%s</b></big>",
-                _(PACKAGE_NAME " could not display the help contents."));
-
-        gtk_message_dialog_format_secondary_text (
-                GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
-
-        gtk_dialog_run (GTK_DIALOG (dialog));
-
-        gtk_widget_destroy (dialog);
-        g_error_free (error);
-#endif
+        gva_help_display (GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW), NULL);
 }
 
 /**
@@ -451,7 +422,36 @@ action_save_errors_cb (GtkAction *action)
 static void
 action_search_cb (GtkAction *action)
 {
-        gtk_window_present (GTK_WINDOW (GVA_WIDGET_SEARCH_WINDOW));
+        GtkWidget *widget;
+
+        gtk_widget_show (GVA_WIDGET_MAIN_SEARCH_HBOX);
+
+        widget = GVA_WIDGET_MAIN_SEARCH_ENTRY;
+        gtk_widget_grab_focus (widget);
+        g_signal_emit_by_name (widget, "changed");
+        gtk_cell_editable_start_editing (GTK_CELL_EDITABLE (widget), NULL);
+}
+
+/**
+ * GVA_ACTION_SHOW_CLONES:
+ *
+ * This toggle action tracks the user's preference for whether to
+ * show cloned games in the main window's game list.
+ **/
+static void
+action_show_clones_cb (GtkToggleAction *action)
+{
+        GError *error = NULL;
+
+        /* This is a bit of a hack.  We want to instantly apply the
+         * user preference, but not while loading the initial value
+         * from GConf.  So we desensitize the action until we're up
+         * and running, and use that to decide what to do here. */
+        if (gtk_action_is_sensitive (GTK_ACTION (action)))
+        {
+                gva_tree_view_update (&error);
+                gva_error_handle (&error);
+        }
 }
 
 /**
@@ -521,7 +521,8 @@ action_start_cb (GtkAction *action)
  * Main menu item: View -> Search Results
  **/
 static void
-action_view_changed_cb (GtkRadioAction *action, GtkRadioAction *current)
+action_view_changed_cb (GtkRadioAction *action,
+                        GtkRadioAction *current)
 {
         GError *error = NULL;
 
@@ -681,6 +682,14 @@ static GtkToggleActionEntry toggle_entries[] =
           NULL,
           NULL,
           NULL,     /* GConf Bridge monitors the state */
+          FALSE },  /* GConf overrides this */
+
+        { "show-clones",
+          NULL,
+          N_("Show _alternate versions of original games"),
+          NULL,
+          NULL,
+          G_CALLBACK (action_show_clones_cb),
           FALSE }   /* GConf overrides this */
 };
 
@@ -689,21 +698,21 @@ static GtkRadioActionEntry view_radio_entries[] =
         { "view-available",
           NULL,
           N_("_Available Games"),
-          NULL,
+          "<Control>1",
           N_("Show all available games"),
           0 },
 
         { "view-favorites",
           NULL,
           N_("_Favorite Games"),
-          NULL,
+          "<Control>2",
           N_("Only show my favorite games"),
           1 },
 
         { "view-results",
           NULL,
           N_("Search _Results"),
-          NULL,
+          "<Control>3",
           N_("Show my search results"),
           2 }
 };
