@@ -45,6 +45,7 @@
 #define GVA_ACTION_REMOVE_FAVORITE      (gva_ui_get_action ("remove-favorite"))
 #define GVA_ACTION_SAVE_ERRORS          (gva_ui_get_action ("save-errors"))
 #define GVA_ACTION_SEARCH               (gva_ui_get_action ("search"))
+#define GVA_ACTION_SHOW_CLONES          (gva_ui_get_action ("show-clones"))
 #define GVA_ACTION_SHOW_PLAY_BACK       (gva_ui_get_action ("show-play-back"))
 #define GVA_ACTION_START                (gva_ui_get_action ("start"))
 #define GVA_ACTION_VIEW_AVAILABLE       (gva_ui_get_action ("view-available"))
@@ -64,6 +65,10 @@
         (gva_ui_get_widget ("main-progress-bar"))
 #define GVA_WIDGET_MAIN_PROPERTIES_BUTTON \
         (gva_ui_get_widget ("main-properties-button"))
+#define GVA_WIDGET_MAIN_SEARCH_ENTRY \
+        (gva_ui_get_widget ("main-search-entry"))
+#define GVA_WIDGET_MAIN_SEARCH_HBOX \
+        (gva_ui_get_widget ("main-search-hbox"))
 #define GVA_WIDGET_MAIN_START_GAME_BUTTON \
         (gva_ui_get_widget ("main-start-game-button"))
 #define GVA_WIDGET_MAIN_STATUSBAR \
@@ -100,31 +105,57 @@
         (gva_ui_get_widget ("preferences-close-button"))
 #define GVA_WIDGET_PREFERENCES_FULL_SCREEN \
         (gva_ui_get_widget ("preferences-full-screen"))
+#define GVA_WIDGET_PREFERENCES_SHOW_CLONES \
+        (gva_ui_get_widget ("preferences-show-clones"))
 #define GVA_WIDGET_PREFERENCES_WINDOW \
         (gva_ui_get_widget ("preferences-window"))
 
 /* Properties Window */
 #define GVA_WIDGET_PROPERTIES_BACK_BUTTON \
         (gva_ui_get_widget ("properties-back-button"))
+#define GVA_WIDGET_PROPERTIES_BIOS_LABEL \
+        (gva_ui_get_widget ("properties-bios-label"))
+#define GVA_WIDGET_PROPERTIES_BIOS_VBOX \
+        (gva_ui_get_widget ("properties-bios-vbox"))
 #define GVA_WIDGET_PROPERTIES_CLOSE_BUTTON \
         (gva_ui_get_widget ("properties-close-button"))
+#define GVA_WIDGET_PROPERTIES_CPU_VBOX \
+        (gva_ui_get_widget ("properties-cpu-vbox"))
 #define GVA_WIDGET_PROPERTIES_FORWARD_BUTTON \
         (gva_ui_get_widget ("properties-forward-button"))
 #define GVA_WIDGET_PROPERTIES_HEADER \
         (gva_ui_get_widget ("properties-header"))
 #define GVA_WIDGET_PROPERTIES_HISTORY_TEXT_VIEW \
         (gva_ui_get_widget ("properties-history-text-view"))
+#define GVA_WIDGET_PROPERTIES_IMPERFECT_COLOR_LABEL \
+        (gva_ui_get_widget ("properties-imperfect-color-label"))
+#define GVA_WIDGET_PROPERTIES_IMPERFECT_GRAPHIC_LABEL \
+        (gva_ui_get_widget ("properties-imperfect-graphic-label"))
+#define GVA_WIDGET_PROPERTIES_IMPERFECT_SOUND_LABEL \
+        (gva_ui_get_widget ("properties-imperfect-sound-label"))
+#define GVA_WIDGET_PROPERTIES_NOTEBOOK \
+        (gva_ui_get_widget ("properties-notebook"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_COCKTAIL_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-cocktail-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_COLOR_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-color-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_EMULATION_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-emulation-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_PROTECTION_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-protection-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_SOUND_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-sound-label"))
+#define GVA_WIDGET_PROPERTIES_SOUND_VBOX \
+        (gva_ui_get_widget ("properties-sound-vbox"))
+#define GVA_WIDGET_PROPERTIES_STATUS_HBOX \
+        (gva_ui_get_widget ("properties-status-hbox"))
+#define GVA_WIDGET_PROPERTIES_STATUS_IMAGE \
+        (gva_ui_get_widget ("properties-status-image"))
+#define GVA_WIDGET_PROPERTIES_VIDEO_VBOX \
+        (gva_ui_get_widget ("properties-video-vbox"))
 #define GVA_WIDGET_PROPERTIES_WINDOW \
         (gva_ui_get_widget ("properties-window"))
 
-/* Search Window */
-#define GVA_WIDGET_SEARCH_ENTRY \
-        (gva_ui_get_widget ("search-entry"))
-#define GVA_WIDGET_SEARCH_FIND_BUTTON \
-        (gva_ui_get_widget ("search-find-button"))
-#define GVA_WIDGET_SEARCH_WINDOW \
-        (gva_ui_get_widget ("search-window"))
-
 G_BEGIN_DECLS
 
 GtkAction *     gva_ui_get_action               (const gchar *action_name);
