@@ -18,6 +18,7 @@
 
 #include "gva-common.h"
 
+#include <errno.h>
 #include <libintl.h>
 #include <locale.h>
 #include <stdlib.h>
@@ -37,9 +38,13 @@
 #include "gva-play-back.h"
 #include "gva-preferences.h"
 #include "gva-properties.h"
-#include "gva-search.h"
 #include "gva-tree-view.h"
 #include "gva-ui.h"
+#include "gva-util.h"
+
+#define SQL_COUNT_ROMS \
+        "SELECT count(*) FROM game WHERE " \
+        "romset NOTNULL AND romset != 'not found'"
 
 static GOptionEntry entries[] =
 {
@@ -63,6 +68,68 @@ static GOptionEntry entries[] =
         { NULL }
 };
 
+static void
+warn_if_no_roms (void)
+{
+        const gchar *sql = SQL_COUNT_ROMS;
+        GtkWidget *dialog;
+        gint rows, columns;
+        gchar **result;
+        glong n_roms;
+        GError *error = NULL;
+
+        if (!gva_db_get_table (sql, &result, &rows, &columns, &error))
+        {
+                gva_error_handle (&error);
+                return;
+        }
+
+        errno = 0;
+        g_return_if_fail (g_strv_length (result) > 1);
+        n_roms = strtol (result[1], NULL, 10);
+        g_strfreev (result);
+
+        if (errno != 0)
+        {
+                g_warning ("%s", g_strerror (errno));
+                return;
+        }
+
+        if (n_roms > 0)
+                return;
+
+        dialog = gtk_message_dialog_new_with_markup (
+                GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW),
+                GTK_DIALOG_DESTROY_WITH_PARENT,
+                GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
+                "<big><b>%s</b></big>",
+                _("No ROM files found"));
+
+#ifdef WITH_GNOME
+        gtk_message_dialog_format_secondary_markup (
+                GTK_MESSAGE_DIALOG (dialog),
+                _("GNOME Video Arcade was unable to locate any ROM files. "
+                  "It could be that MAME is misconfigured or that no ROM "
+                  "files are installed. Click <b>Help</b> for more details "
+                  "and troubleshooting tips."));
+
+        gtk_dialog_add_button (
+                GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
+#else
+        gtk_message_dialog_format_secondary_markup (
+                GTK_MESSAGE_DIALOG (dialog),
+                _("GNOME Video Arcade was unable to locate any ROM files. "
+                  "It could be that MAME is misconfigured or no ROM files "
+                  "are installed. Consult the user documentation for more "
+                  "details and troubleshooting tips."));
+#endif
+
+        if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_HELP)
+                gva_help_display (GTK_WINDOW (dialog), "troubleshooting");
+
+        gtk_widget_destroy (dialog);
+}
+
 static void
 start (void)
 {
@@ -82,39 +149,46 @@ start (void)
 
         if (gva_db_needs_rebuilt ())
         {
-                gboolean success = TRUE;
-
                 gva_main_progress_bar_show ();
 
-                success &= gva_main_build_database (&error);
-                gva_error_handle (&error);
+                if (!gva_main_build_database (&error))
+                {
+                        gva_error_handle (&error);
+                        return;
+                }
 
                 gva_main_progress_bar_set_fraction (0.0);
 
-                success &= gva_main_analyze_roms (&error);
-                gva_error_handle (&error);
+                if (!gva_main_analyze_roms (&error))
+                {
+                        gva_error_handle (&error);
+                        return;
+                }
 
                 gva_main_progress_bar_hide ();
-
-                if (!success)
-                        return;
         }
         else if (gva_audit_detect_changes ())
         {
-                gboolean success;
-
                 gva_main_progress_bar_show ();
 
-                success = gva_main_analyze_roms (&error);
-                gva_error_handle (&error);
+                if (!gva_main_analyze_roms (&error))
+                {
+                        gva_error_handle (&error);
+                        return;
+                }
 
                 gva_main_progress_bar_hide ();
-
-                if (!success)
-                        return;
         }
 
+        /* Do this after ROMs are analyzed. */
+        if (!gva_main_init_search_completion (&error))
+        {
+                gva_error_handle (&error);
+                return;
+        }        
+
         gtk_action_set_sensitive (GVA_ACTION_SEARCH, TRUE);
+        gtk_action_set_sensitive (GVA_ACTION_SHOW_CLONES, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_AVAILABLE, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_FAVORITES, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_RESULTS, TRUE);
@@ -129,6 +203,9 @@ start (void)
                 gva_tree_view_update (&error);
                 gva_error_handle (&error);
         }
+
+        /* Present a helpful dialog if no ROMs were found. */
+        warn_if_no_roms ();
 }
 
 gint
@@ -203,17 +280,12 @@ main (gint argc, gchar **argv)
         gva_play_back_init ();
         gva_preferences_init ();
         gva_properties_init ();
-        gva_search_init ();
 
-#ifdef CATEGORY_FILE
         gva_categories_init (&error);
         gva_error_handle (&error);
-#endif
 
-#ifdef HISTORY_FILE
         gva_history_init (&error);
         gva_error_handle (&error);
-#endif
 
         gtk_init_add ((GtkFunction) start, NULL);
 
